#ifndef _DEFINED_NetWorkDLS_Standard_Windows_Function_Library_Header
#define _DEFINED_NetWorkDLS_Standard_Windows_Function_Library_Header
////////////////////////////////////////////////////////////////////////////////////////////

////////////////////////////////////////////////////////////////////////////////////////////
/////////////( External Definitions )/////////////

#define DllImport extern "C" __declspec( dllimport )

//----------( External Open / Save Dialog Definitions )------
#define OFD 1
#define SFD 2

//----------( External Data Base System Definitions )------
#define MaxDataEntries   102400

//----------( External Query System Definitions )------
#define MaxQuerySize 1024

//----------( External File Access Definitions )------
#define FAccess  6   // Check for read and write permission
#define FRead    4   // Check for read permission
#define FWrite   2   // Check for write permission
#define FExecute 1   // Execute (Ignored)
#define FExist   0   // Check for existence of file

////////////////////////////////////////////////////////////////////////////////////////////

//----------( Global Structures )------
struct _QuerySystem{
    char *Buffer[MaxQuerySize];
    int Used;
    int Free;
};

struct _BufferSystem{
    int BufferSize;
    int TotalSize;
    int Position;
    char *Buffer;
};

struct _DataBaseSystem{
    char *DataBase;

    int Name[MaxDataEntries];
    int Data[MaxDataEntries];

    int NameValues;
    int DataValues;

    int MaxSize;
    int DataBaseSize;
};

//----------( File IO Exports )------
DllImport BOOL BufferCopyFile(char *, char *, int);

//----------( Memory Exports )------
DllImport void *Allocate(int);
DllImport int Free(void *);
DllImport int ClearMemory(char *, int);
DllImport int MemCopy(char *, char *, int);
DllImport int MemCopyLong(char *, long);
DllImport int MemCopyInt(char *, int);

//----------( Math Exports )------
DllImport int SquareRoot (int);

DllImport int LoByte (unsigned int);
DllImport int HiByte (unsigned int);

DllImport int LongLength(long);
DllImport int IntLength(int);

DllImport int ReverseLong(long);
DllImport int ReverseInt(int);

DllImport DWORD VersionToLong(int, int, int, int);
DllImport BOOL LongToVersion(DWORD, int *, int *, int *, int *);

//----------( Conversion Exports )------
DllImport char * LongChar (DWORD);
DllImport char * FloatChar (float);
DllImport char * DoubleChar (double);
DllImport char * IntChar (int);
DllImport DWORD CharLong (char *);
DllImport float CharFloat (char *);
DllImport double CharDouble (char *);
DllImport int CharInt (char *);

//----------( Windows Exports )------
DllImport void ErrorMessage(HWND, char *);
DllImport void AlertMessage(HWND, char *,char *);

DllImport void CenterWindow (HWND);
DllImport void TextBoxWrite (HWND, char *);
DllImport void Set_Text (HWND, char *);

DllImport char * Get_Text (HWND);

DllImport int IsMouseOverHwnd(HWND);
DllImport int OSFileDialog(HWND, char *, char *, char *, char *, char *, DWORD, DWORD);

DllImport LRESULT CALLBACK Set_Color(int,int,int);

//----------( String Exports )------
DllImport char * LCase (char *);
DllImport char * UCase (char *);

DllImport int ReverseString(char *, int);

DllImport char *StringScan (char *, int, int);
DllImport int SearchString(char *, char *);

DllImport int ReplaceStrings (char *, char *, char *, char *);
DllImport int ReplaceCharacter(char *, char *, char, char);

DllImport BOOL CompareNCString(char *, char *);
DllImport BOOL CompareCSString(char *, char *);

DllImport char *AppendStrings(char *, char *, int, int);
DllImport char *GetFlagedValue(char *, int, int);
DllImport int CompareFlagedString(char *, char *);

DllImport int SimpleCipherString(char *, int);

//----------( System Exports )------
DllImport char * Get_Time (void);
DllImport char * Get_LongDate (void);
DllImport char * Get_ShortDate (void);

DllImport BOOL IsDirectory(char *);
DllImport BOOL  FileAccess(char *, short);
DllImport DWORD Get_FileSize(char *);

DllImport char * Get_TempDirectory (void);
DllImport char * Get_WindowsDirectory (void);
DllImport char * Get_SystemDirectory (void);
DllImport char * Get_CurrentDirectory (void);

DllImport BOOL IsWinNT(void);

DllImport char * Get_OsVersion (void);
DllImport char * Get_UserName (void);
DllImport char * Get_MachineName (void);

DllImport void SetApplicationPriority(HANDLE, HANDLE, short, short, BOOL, BOOL);

//----------( Registry Exports )------
DllImport int DeleteRegistryValue(HKEY, LPCTSTR, LPCTSTR);

DllImport int CreateRegistryKey(HKEY, LPCTSTR);
DllImport int DeleteRegistryKey(HKEY, LPCTSTR);

DllImport int Set_BinaryRegistryValue(HKEY, LPCTSTR, LPCTSTR, PVOID, DWORD);
DllImport int Get_BinaryRegistryValue(HKEY, LPCTSTR, LPCTSTR, PVOID, DWORD&);

DllImport int Set_DWORDRegistryValue(HKEY, LPCTSTR, LPCTSTR, DWORD);
DllImport int Get_DWORDRegistryValue(HKEY, LPCTSTR, LPCTSTR, DWORD&);

DllImport int Set_StringRegistryValue(HKEY, LPCTSTR, LPCTSTR, LPCTSTR);
DllImport int Get_StringRegistryValue(HKEY, LPCTSTR, LPCTSTR, LPTSTR, DWORD&);

//----------( Query System Exports )------
DllImport BOOL InitilizeQuery(struct _QuerySystem *);
DllImport BOOL FreeQuery(struct _QuerySystem *);

DllImport BOOL InsertQueryItem(struct _QuerySystem *, char *, int);
DllImport BOOL AddQueryItem(struct _QuerySystem *, char *);
DllImport BOOL DeleteQueryItem(struct _QuerySystem *, int);

DllImport char *ReadQueryItem(struct _QuerySystem *, int);
DllImport char *GetQueryItem(struct _QuerySystem *, int);

//----------( Buffer System Exports )------
DllImport BOOL InitilizeBufferSystem(struct _BufferSystem *, int);
DllImport BOOL FreeBufferSystem(struct _BufferSystem *);
DllImport BOOL AppendToBuffer(struct _BufferSystem *, char *, int);
DllImport BOOL ReadFromBuffer(struct _BufferSystem *, int, char *);

//----------( Data Base System Exporte )------
DllImport BOOL InitializeDBS(struct _DataBaseSystem *, int);
DllImport BOOL FreeDBS(struct _DataBaseSystem *);
DllImport BOOL CreateDBS(struct _DataBaseSystem *);

DllImport int AddEntryDBS(struct _DataBaseSystem *, char *, char *);
DllImport int ReplaceEntryDBS(struct _DataBaseSystem *, char *, char *);

DllImport int IndexDataBaseDBS(struct _DataBaseSystem *);

DllImport char *RetreiveNameByPositionDBS(struct _DataBaseSystem *, int);

DllImport char *RetreiveDataByFieldNameDBS(struct _DataBaseSystem *, char *);
DllImport char *RetreiveDataByPositionDBS(struct _DataBaseSystem *, int);

DllImport int DeleteEntryByFeildNameDBS(struct _DataBaseSystem *, char *);
DllImport int DeleteEntryByAbsoluteDBS(struct _DataBaseSystem *, int);

DllImport int SearchForPositionDBS(struct _DataBaseSystem *, char *);
DllImport int SearchForAbsoluteDBS(struct _DataBaseSystem *, char *);

DllImport int AbsoluteToPositionDBS(struct _DataBaseSystem *, int);
DllImport int PositionToAbsoluteDBS(struct _DataBaseSystem *, int);

//----------( DateTime Exports )------
DllImport void LongToDate(DWORD, int *, int *, int *);
DllImport void LongToTime(DWORD, int *, int *, int *);

DllImport DWORD DateToLong(int, int, int);
DllImport DWORD TimeToLong(int, int, int);

//----------( List Box  Exports )------
DllImport int InsertListBoxItem(HWND, char *, int);
DllImport int ClearListBox(HWND);
DllImport int DeleteListBoxItem(HWND, int);
DllImport int CountListBoxItems(HWND);
DllImport int SelectMultipleListBoxItem(HWND, int, BOOL);
DllImport int SelectListBoxItem(HWND, int);
DllImport int CurrentListBoxItem(HWND);
DllImport char *ListBoxItemText(HWND, int);
DllImport int ListBoxItemLength(HWND, int);
DllImport int HorizontalListBoxExtent(HWND, int);

//----------( GLLogo Control Exports )------
DllImport BOOL NetGLLogo(HWND);
DllImport BOOL IsNetGLLogoActive(void);
DllImport void EndNetGLLogo(void);
DllImport HWND NetGLLogoHandle(void);

//----------( NetLogo Control Exports )------
DllImport BOOL NetLogo(HWND);
DllImport BOOL IsNetLogoActive(void);
DllImport void EndNetLogo(void);
DllImport HWND NetLogoHandle(void);

////////////////////////////////////////////////////////////////////////////////////////////
#endif

